@@ -1,15 +1,17 @@
-from typing import Optional
+from typing import TYPE_CHECKING, Optional
 
 from pipenv.patched.pip._vendor.packaging.utils import canonicalize_name
 
 from pipenv.patched.pip._internal.distributions.base import AbstractDistribution
-from pipenv.patched.pip._internal.index.package_finder import PackageFinder
 from pipenv.patched.pip._internal.metadata import (
     BaseDistribution,
     FilesystemWheel,
     get_wheel_distribution,
 )
 
+if TYPE_CHECKING:
+    from pipenv.patched.pip._internal.index.package_finder import PackageFinder
+
 
 class WheelDistribution(AbstractDistribution):
     """Represents a wheel distribution.
@@ -33,7 +35,7 @@ class WheelDistribution(AbstractDistribution):
 
     def prepare_distribution_metadata(
         self,
-        finder: PackageFinder,
+        finder: "PackageFinder",
         build_isolation: bool,
         check_build_deps: bool,
     ) -> None:
