@@ -65,10 +65,10 @@ if DEBUNDLED:
     vendored("packaging")
     vendored("packaging.version")
     vendored("packaging.specifiers")
-    vendored("pep517")
     vendored("pkg_resources")
     vendored("platformdirs")
     vendored("progress")
+    vendored("pyproject_hooks")
     vendored("requests")
     vendored("requests.exceptions")
     vendored("requests.packages")
@@ -110,7 +110,7 @@ if DEBUNDLED:
     vendored("rich.style")
     vendored("rich.text")
     vendored("rich.traceback")
-    vendored("tenacity")
-    vendored("tomli")
+    if sys.version_info < (3, 11):
+        vendored("tomli")
     vendored("truststore")
     vendored("urllib3")
