@@ -41,20 +41,20 @@ def do_outdated(project, pypi_mirror=None, pre=False, clear=False):
         for package in lockfile.get(category, []):
             try:
                 updated_packages[package] = parse_version(
-                    lockfile[category][package]["version"]
+                    lockfile[category][package]["version"].replace("==", "")
                 )
             except KeyError:  # noqa: PERF203
                 pass
     outdated = []
     skipped = []
-    for package in packages:
+    for package in packages.keys():  # noqa: PLC0206
         norm_name = pep423_name(package)
-        if norm_name in updated_packages:
+        if norm_name in updated_packages.keys():
             version = packages[package]
             if isinstance(version, Mapping):
-                version = parse_version(version.get("version"))
+                version = parse_version(version.get("version", "").replace("==", ""))
             else:
-                version = parse_version(version)
+                version = parse_version(version.replace("==", ""))
             if updated_packages[norm_name] != version:
                 outdated.append(
                     package_info(package, str(version), str(updated_packages[norm_name]))
@@ -66,11 +66,10 @@ def do_outdated(project, pypi_mirror=None, pre=False, clear=False):
             name_in_pipfile = project.get_package_name_in_pipfile(
                 package, category=category
             )
-            if name_in_pipfile:
+            pipfile_section = project.get_pipfile_section(category)
+            if name_in_pipfile and name_in_pipfile in pipfile_section:
                 required = ""
-                version = get_version(
-                    project.get_pipfile_section(category)[name_in_pipfile]
-                )
+                version = get_version(pipfile_section[name_in_pipfile])
                 rdeps = reverse_deps.get(canonicalize_name(package))
                 if isinstance(rdeps, Mapping) and "required" in rdeps:
                     required = " {rdeps['required']} required"
@@ -85,11 +84,10 @@ def do_outdated(project, pypi_mirror=None, pre=False, clear=False):
                     fg="yellow",
                     err=True,
                 )
-    if not outdated:
-        click.echo(click.style("All packages are up to date!", fg="green", bold=True))
-        sys.exit(0)
-    for package, old_version, new_version in outdated:
+    for package, old_version, new_version in set(outdated).union(set(skipped)):
         click.echo(
             f"Package {package!r} out-of-date: {old_version!r} installed, {new_version!r} available."
         )
+    if not outdated:
+        click.echo(click.style("All packages are up to date!", fg="green", bold=True))
     sys.exit(bool(outdated))
